pub struct GenerateOptions {
pub languages: Vec<TargetLanguage>,
pub source: Utf8PathBuf,
pub out_dir: Utf8PathBuf,
pub config_override: Option<Utf8PathBuf>,
pub format: bool,
pub crate_filter: Option<String>,
pub metadata_no_deps: bool,
}Fields
languages: Vec<TargetLanguage>Languages to generate bindings for
source: Utf8PathBufPath to the UDL or library file
out_dir: Utf8PathBufDirectory to write generated files.
config_override: Option<Utf8PathBuf>Path to the config file to use, if None bindings generators will load
[crate-root]/uniffi.toml
format: boolRun the generated code through a source code formatter
crate_filter: Option<String>Limit binding generate to a single crate
metadata_no_deps: boolExclude dependencies when running “cargo metadata”. This will mean external types may not be resolved if they are implemented in crates outside of this workspace. This can be used in environments when all types are in the namespace and fetching all sub-dependencies causes obscure platform specific problems.